@@ -1,7 +1,7 @@
+# 2022.8.25  _book:booked (lem) 
 # 2022.8.19 , cp from docjson 
 # 2022.8.14 , depend on spacy3.4.1 lg model 
 import json, traceback,sys, time,  fileinput, os, en
-
 #ex_token = lambda t : f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" if t.text == t.text.lower() else f"{t.text}_{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}"
 
 def kps(sid, snt, doc, with_tok:bool=False): 
@@ -10,42 +10,43 @@ def kps(sid, snt, doc, with_tok:bool=False):
 
 	_kps = []
 	[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
-	[ _kps.append(f"{t.lemma_}:{t.text.lower()}") for t in doc]  # book:booked,  added 2022.8.21
-	[ _kps.append(f"{t.tag_}:{t.lemma_}_{t.pos_}") for t in doc]  # VBD:book_VERB,  added 2022.8.21
-	[ _kps.append(f"{t.dep_}:{t.head.lemma_}_{t.head.pos_}:{t.pos_}_{t.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
-	[ _kps.append(f"~{t.dep_}:{t.lemma_}_{t.pos_}:{t.head.pos_}_{t.head.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
-	[ _kps.append(f"NP:{doc[sp.end-1].lemma_}_{doc[sp.end-1].pos_}:{sp.text.lower()}") for sp in doc.noun_chunks ]
+	[ _kps.append(f"_{t.lemma_}:{t.text.lower()}") for t in doc]  # _book:booked,  added 2022.8.21
+	[ _kps.append(f"{t.tag_}:{t.pos_}_{t.lemma_}") for t in doc]  # VBD:VERB_book,  added 2022.8.25
+	[ _kps.append(f"{t.dep_}:{t.head.pos_}_{t.head.lemma_}:{t.pos_}_{t.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
+	[ _kps.append(f"~{t.dep_}:{t.pos_}_{t.lemma_}:{t.head.pos_}_{t.head.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
+	[ _kps.append(f"NP:{doc[sp.end-1].pos_}_{doc[sp.end-1].lemma_}:{sp.text.lower()}") for sp in doc.noun_chunks ]
 	_kps.append( f"stype:" +  "simple_snt" if en.simple_sent(doc) else "complex_snt" )
 	if en.compound_snt(doc) : _kps.append("stype:compound_snt")
 
 	# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
 	for lem, pos, type, chunk in en.kp_matcher(doc): #brink:NOUN:pp:on the brink
-		_kps.append(f"{type}:{lem}_{pos}:{chunk}")
+		_kps.append(f"{type}:{pos}_{lem}:{chunk}")
 	for trpx, row in en.dep_matcher(doc): #[('svx', [1, 0, 2])] ## consider:VERB:vnpn:**** 
 		verbi = row[0] #consider:VERB:be_vbn_p:be considered as
-		_kps.append(f"{trpx}:{doc[verbi].lemma_}_{doc[verbi].pos_}")
+		_kps.append(f"{trpx}:{doc[verbi].pos_}_{doc[verbi].lemma_}")
 		if trpx == 'sva' and doc[row[0]].lemma_ == 'be': # fate is sealed, added 2022.7.25   keep sth. stuck
-			_kps.append(f"sbea:{doc[row[1]].lemma_}_{doc[row[1]].pos_}:{doc[row[2]].pos_}_{doc[row[2]].lemma_}")
+			_kps.append(f"sbea:{doc[row[1]].pos_}_{doc[row[1]].lemma_}:{doc[row[2]].pos_}_{doc[row[2]].lemma_}")
 		
 	# last to be called, since NP is merged
 	for row in en.verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
 		if len(row) == 4: 
 			verbi, ibeg, iend, chunk = row
 			if doc[verbi].lemma_.isalpha() : 
-				_kps.append(f"verbnet:{doc[verbi].lemma_}_{doc[verbi].pos_}:{chunk}")
+				_kps.append(f"verbnet:{doc[verbi].pos_}_{doc[verbi].lemma_}:{chunk}")
 
 	for name,ibeg,iend in en.post_np_matcher(doc): #added 2022.7.25
 		if name in ('v_n_vbn','v_n_adj'): 
-			_kps.append(f"{name}:{doc[ibeg].lemma_}_{doc[ibeg].pos_}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}")
+			_kps.append(f"{name}:{doc[ibeg].pos_}_{doc[ibeg].lemma_}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}")
 
 	actions = []
 	actions.append( {'_id': sid, '_source': {'type':'snt', 'snt':snt, 'postag':postag,  'src': sid,  'tc': len(doc), 'kps': list(set(_kps)) 	} } )
 	if with_tok: [ actions.append( {'_id': f"{sid}-tok-{t.i}", '_source': {"type":"tok", "src":sid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ } }) for t in doc ] 
 	return actions
 
-def kps_esjson(infile, with_tok:bool=False):
-	''' gzjc.docjsonlg.3.4.1.gz -> gzjc.esjson | 2022.8.19 '''
-	outfile = infile.split('.')[0] + f".esjson"
+def kps_esjson(infile, outfile=None,  with_tok:bool=False):
+	''' gzjc.jsonlg.3.4.1.gz -> gzjc.esjson | 2022.8.19 '''
+	if outfile is None: outfile = infile.split('.json')[0] + f".esjson"
+	if os.path.exists(f"{outfile}.gz"):  os.remove(f"{outfile}.gz")
 	start = time.time()
 	print ("started:", infile ,  ' -> ',  outfile, flush=True)
 	with open(outfile, 'w') as fw: 
@@ -60,7 +61,6 @@ def kps_esjson(infile, with_tok:bool=False):
 	os.system(f"gzip -f -9 {outfile}")
 	print(f"{infile} is finished, \t| using: ", time.time() - start) 
 
-
 if __name__	== '__main__':
 	import fire 
 	fire.Fire(kps_esjson)
