@@ -1,7 +1,7 @@
 # 2022.2.9, http://verbs.colorado.edu/verb-index/vn/consider-29.9.php#consider-29.9-1-1-1
 import spacy, traceback, sys
 from spacy.matcher import Matcher
-if not hasattr(spacy,'nlp'): spacy.nlp	= spacy.load('en_core_web_sm') #if not 'nlp' in dir(): nlp	= spacy.load('en_core_web_sm')  
+if not hasattr(spacy,'nlp'): spacy.nlp	= spacy.load('en_core_web_lg') #if not 'nlp' in dir(): nlp	= spacy.load('en_core_web_sm')  
 
 matcher	 = Matcher(spacy.nlp.vocab)  # :1 , verb's offset 
 NP_start = {"ENT_TYPE": "NP", "IS_SENT_START": True}
