@@ -8,8 +8,7 @@ import warnings
 warnings.filterwarnings("ignore")
 
 if not hasattr(requests, 'eshost'):
-	requests.eshost	= os.getenv("eshost", "172.17.0.1") 
-	requests.esport	= int(os.getenv("esport", 9200))
+	requests.eshost	= os.getenv("eshost", "es.corpusly.com:9200") 
 	requests.es		= Elasticsearch([ f"http://{requests.eshost}" ])  
 
 config = {  
@@ -100,6 +99,7 @@ config = {
 			"score": { "type": "float"},
 			"ratio": { "type": "float", "index": "false"},
 			"memo": { "type": "keyword", "index": "false"}, # to store some memo info, for show only
+			"sent": { "type": "keyword", "index": "false"},
 			"offset": { "type": "float"},
 			"final_score": { "type": "float"},
 			"sid": { "type": "keyword"},
@@ -131,7 +131,8 @@ config = {
 			"gpos": { "type": "keyword"},
 			"glem": { "type": "keyword"},
 
-			"ap": { "type": "keyword"},
+			"frame": { "type": "keyword"},
+			"stype": { "type": "keyword"},
 			"page": { "type": "keyword"},
 			"pen": { "type": "keyword"},
 			"label": { "type": "keyword"},
@@ -412,11 +413,38 @@ def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10):
 
 phrase_num = lambda phrase, cp='clec', topk=10: match_phrase(phrase, cp, topk)["hits"]["total"]["value"]
 
-addpat	= lambda s : f"{s}_[^ ]*" if not s.startswith('_') else f"[^ ]*{s}_[^ ]*"   # if the last one, add $ 
+addpat	= lambda s : f"{s}_[^ ]*" if not s.startswith('_') else f"[^ ]*{s}[^ ]*"   # if the last one, add $ 
 rehyb   = lambda hyb: ' '.join([ addpat(s) for s in hyb.split()])  #'the_[^ ]* [^ ]*_NNS_[^ ]* of_[^ ]*'
 heads   = lambda chunk:  ' '.join([s.split('_')[0].lower() for s in chunk.split()])		#the_the_DT_DET adventures_adventure_NNS_NOUN of_of_IN_ADP
-def hybchunk(hyb:str='the _NNS of', index:str='gzjc', size:int= -1, topk:int=10):
+def hybchunk(hyb:str='the _NNS of', index:str='dic', size:int= -1, topk:int=10):
 	''' the _NNS of -> {the books of: 13, the doors of: 7} , added 2021.10.13 '''
+	sql= { "query": {  "match_phrase": { "postag": hyb  } },  "_source": ["postag"], "size":  size}
+	res = requests.post(f"http://{requests.eshost}/{index}/_search/", json=sql).json()
+	si = Counter()
+	repat = rehyb(hyb)
+	for ar in res['hits']['hits']: 
+		postag =  ar["_source"]['postag']
+		m= re.search(repat,postag) #the_the_DT_DET adventures_adventure_NNS_NOUN of_of_IN_ADP
+		if m : si.update({ heads(m.group()):1})
+	return si.most_common(topk)
+
+if __name__ == "__main__": 
+	#print ( sql("select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"))
+	#print ( sqlrow("show tables")) 
+	print (hybchunk(index='clec')) 
+
+'''
+the_[^ ]* [^ ]*_NNS_[^ ]* of_[^ ]* 
+_^ wxpecially_wxpecially_ADV_RB the_the_DET_DT songs_song_NOUN_NNS of_of_ADP_IN _PROPN_NNP _PUNCT_.
+PUT twitter/_mapping 
+{
+  "properties": {
+    "email": {
+      "type": "keyword"
+    }
+  }
+}
+
 	sql= {
   "query": { 
     "bool": { 
@@ -428,28 +456,7 @@ def hybchunk(hyb:str='the _NNS of', index:str='gzjc', size:int= -1, topk:int=10)
   },
   "size":  size
 }
-	res = requests.post(f"http://{requests.eshost}/{index}/_search/", json=sql).json()
-	si = Counter()
-	repat = rehyb(hyb)
-	for ar in res['hits']['hits']: 
-		postag =  ar["_source"]['postag']
-		m= re.search(repat,postag) #the_the_DT_DET adventures_adventure_NNS_NOUN of_of_IN_ADP
-		if m : si.update({ heads(m.group()):1})
-	return si.most_common(topk)
 
-if __name__ == "__main__": 
-	print ( sql("select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"))
-	print ( sqlrow("show tables")) 
-
-'''
-PUT twitter/_mapping 
-{
-  "properties": {
-    "email": {
-      "type": "keyword"
-    }
-  }
-}
 
 
 PUT my_index
@@ -544,4 +551,14 @@ from dic.word_awl import word_awl
 def corpus_word_awl(index:str='gzjc', topk:int=10): 
 	return (si:= Counter(), [si.update({s:i}) for s,i in rows(f"select lem, count(*) from {index} where type = 'tok' group by lem") if s in word_awl ], si.most_common(topk))[-1]
 
+GET /dic/_search
+{
+  "query": {
+    "match_phrase": {
+      "postag": "the _NNS of"
+    }
+  } ,
+  "_source": ["postag"],
+  "size":-1
+}
 '''
\ No newline at end of file
