@@ -84,7 +84,7 @@ class ES(object):
 		self.es	  = Elasticsearch([ f"http://{host}:{port}" ])  
 		requests.eshost	= host
 		requests.esport	= port
-		requests.es		= Elasticsearch([ f"http://{requests.host}:{requests.port}" ])  
+		requests.es		= Elasticsearch([ f"http://{host}:{port}" ])  
 
 	def list(self): 
 		''' list current index, show tables '''
