@@ -34,6 +34,21 @@ class Util(object):
 		self.my_conn.commit()
 		print(">> finished:", infile, tab)
 
+	def loadst(self, infile): 
+		''' st(s, t)  '''
+		print ("start to load", infile, flush=True)
+		name = infile.lower().split('.')[0] 
+		self.cursor = self.my_conn.cursor()
+		self.cursor.execute(f"drop TABLE if exists {name}")
+		self.cursor.execute(f"CREATE TABLE if not exists {name}(s varchar(128) COLLATE latin1_bin not null primary key, t text not null) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		for line in fileinput.input(infile):
+			try:
+				self.cursor.execute(f"insert ignore into {name}(s,t) values(%s,%s)",line.strip().split("\t") )
+			except Exception as e:
+				print("ex:", e, line)
+		self.my_conn.commit()
+		print(">> finished:", infile)
+
 	def loadsi(self, infile): 
 		''' si(s, i)  '''
 		print ("start to load", infile, flush=True)
