@@ -1,7 +1,6 @@
 # 2022.6.30 | pip install transformers torch  | 
 from uvirun import *
 import re, os, json, math #torch
-
 model	= os.getenv('gec_model', "/grammar_error_correcter_v1")
 device	= int ( os.getenv('gec_cuda', -1) )
 
@@ -35,9 +34,10 @@ def gecsnts(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_
 	return dic
 
 @app.get('/gec', tags=["gec"])
-def gecsnts_get(snts:str="She has ready.|It are ok.", sepa:str="|", max_length:int=128,  do_sample:bool=False, batch_size:int=64, unchanged_ratio:float=0.45, len_ratio:float=0.5):
-	''' return {'She has ready.': 'She is ready.'}, 'It are ok.': 'It is ok.'}, based on local model, no REDIS '''
-	return gecsnts( snts.split(sepa), max_length,  do_sample, batch_size, unchanged_ratio, len_ratio)
+def gecsnts_get(snt:str="She has ready.", max_length:int=128,  do_sample:bool=False, batch_size:int=64, unchanged_ratio:float=0.45, len_ratio:float=0.5):
+	''' # [{'snt': 'She has ready.', 'trans': 'She is ready.', 'changed': True}], based on local model, no REDIS '''
+	dic = gecsnts( [snt], max_length,  do_sample, batch_size, unchanged_ratio, len_ratio)
+	return [ { 'snt': snt, 'trans': dic.get(snt,snt), 'changed':  dic.get(snt,snt) != snt }]
 
 if __name__ == "__main__":   #{'She has ready.': 'She is ready.', 'It are ok.': 'It is ok.'}
-	print ( "local gecsnts",  gecsnts() )
\ No newline at end of file
+	print ( "local gecsnts",  gecsnts_get() )
\ No newline at end of file
