@@ -13,17 +13,18 @@ def rows(sql:str="show tables"):
 	return res 
 
 @app.get('/kpsi/snts', tags=["kpsi"], response_class=HTMLResponse)
-def kpsi_snts(s:str="open:VERB:dobj:NOUN:door", cp:str='dic', hl_words:str="open,door", topk:int=10): 
+def kpsi_snts(s:str="open:VERB:dobj:NOUN:door", cp:str='dic', hl_words:str="open,door", topk:int=10, sntsum:bool=True): 
 	''' return HTML <ol><li> , 2022.7.24 '''
 	from dic import lemma_lex
-	sids = rows(f"select t from {cp} where s = '{s}' limit 1")
+	sids = rows(f"select i, t from {cp} where s = '{s}' limit 1")
 	if sids and len(sids) > 0 :
-		sids = ",".join([str(sid) for sid in sids[0][0].split(',')[0:topk] ])
+		cnt = sids[0][0]
+		sids = ",".join([str(sid) for sid in sids[0][1].split(',')[0:topk] ])
 	snts = rows(f"select snt from {cp}_snt where sid in ({sids})")
 	words = '|'.join([ '|'.join(list(lemma_lex.lemma_lex[w])) for w in hl_words.strip().split(',') if w in lemma_lex.lemma_lex])
 	arr = [re.sub(rf'\b({words})\b', r'<font color="red">\g<0></font>', snt[0]) if words else snt[0] for snt in snts]
 	html = "\n".join([f"<li>{snt}</li>" for snt in arr])
-	return HTMLResponse(content=f"<ol>{html}</ol>")
+	return HTMLResponse(content=f"<ol> <b>{cnt}</b> Sentences {html}</ol>" if sntsum else f"<ol>{html}</ol>")
 
 @app.get('/kpsi/kndata', tags=["kpsi"])
 def kn_data(sumkey='knowledge:NOUN:~dobj', cps:str='clec', cpt:str='dic', slike:str="knowledge:NOUN:~dobj:VERB:%", tail:bool=False): 
@@ -36,8 +37,8 @@ def kn_data(sumkey='knowledge:NOUN:~dobj', cps:str='clec', cpt:str='dic', slike:
 		df[f'{cpt}_sum'] = rows(f"select i from {cpt} where s ='{sumkey}' limit 1")[0][0]
 		df = df.sort_values(df.columns[0], ascending=False) #.astype(int)
 		return [ {"index": index.split(':')[-1] if tail else index
-		,f'#{cps}':int(row[cps]),f'Σ{cps}':int(row[f'{cps}_sum'])
-		,f'#{cpt}':int(row[cpt]),f'Σ{cpt}':int(row[f'{cpt}_sum'])
+		,cps:int(row[cps]),f'{cps}_sum':int(row[f'{cps}_sum'])
+		,cpt:int(row[cpt]),f'{cpt}_sum':int(row[f'{cpt}_sum']) 
 		,'keyness':likelihood(row[cps],row[cpt],row[f'{cps}_sum'],row[f'{cpt}_sum'])}  for index, row in df.iterrows()] 
 	except Exception as e:
 		print("kn_data ex:", e) 
@@ -60,15 +61,20 @@ def kntrp(sarr:list=['open:VERB:dobj:NOUN:door','close:VERB:dobj:NOUN:door','kno
 		df = pd.DataFrame({cps: sicps, cpt: sicpt, f'{cps}_sum': { sumarr.get(s,s): i  for s,i in sumcps.items()}, f'{cpt}_sum': { sumarr.get(s,s): i  for s,i in sumcpt.items()}  }).fillna(0)
 		#df = df.sort_values(df.columns[0], ascending=False) 
 		return [ {"index": index
-		,f'#{cps}':int(row[cps]),f'Σ{cps}':int(row[f'{cps}_sum'])
-		,f'#{cpt}':int(row[cpt]),f'Σ{cpt}':int(row[f'{cpt}_sum'])
+		,cps:int(row[cps]),f'{cps}_sum':int(row[f'{cps}_sum'])
+		,cpt:int(row[cpt]),f'{cpt}_sum':int(row[f'{cpt}_sum'])
 		,'keyness':likelihood(row[cps],row[cpt],row[f'{cps}_sum'],row[f'{cpt}_sum'])}  for index, row in df.iterrows()] 
 	except Exception as e:
 		print("kntrp ex:", e) 
 		return []
 
 if __name__ == '__main__':
-	print (kntrp([
+	#print (kpsi_flare(), flush=True) 
+	uvicorn.run(app, host='0.0.0.0', port=80)
+
+'''
+
+print (kntrp([
   "open:VERB:dobj:NOUN:door",
   "close:VERB:dobj:NOUN:door",
   "knowledge:NOUN:~dobj:VERB:learn",
@@ -81,9 +87,7 @@ if __name__ == '__main__':
 "employee:NOUN:amod:ADJ:new",
 "hire:VERB:dobj:NOUN:employee",
 "be:AUX:nsubj:NOUN:education"]), flush=True)
-	#uvicorn.run(app, host='0.0.0.0', port=80)
 
-'''
 @app.get('/kpsi/si', tags=["kpsi"])
 def si(sql,asdic:bool=True): return { s:int(i) for s,i in rows(sql)} if asdic else [ (s,int(i)) for s,i in rows(sql)]
 
@@ -99,4 +103,18 @@ def image_endpoint(*, vector):
 
 mysqldump -uroot -pcikuutest! --port 3307 --host=172.17.0.1 kpsi dic dic_snt --result-file=dic.sql
 
+@app.get('/kpsi/flare1', tags=["kpsi"])
+def kpsi_flare1(lem:str="open", cp:str="dic"):
+	# https://echarts.apache.org/examples/data/asset/data/flare.json
+	i = rows(f"select i from {cp} where s ='LEM:{lem}' limit 1")[0][0]
+	dic = { "name": f"{lem}[{i}]", "children":[] }
+	for w, i in rows(f"select s,i from {cp} where s like '{lem}:%' and s not like '{lem}:%:%'"): #select s,i from {cp} where s in ('{lem}:VERB','{lem}:NOUN','{lem}:ADJ','{lem}:ADV')
+		a = {"name": f"{w}[{i}]", "children":[]}
+		for s,i in rows(f"select s,i from {cp} where s like '{w}:%' and s not like '{w}:%:%'"):
+			b = {"name": f"{s}[{i}]", "value": i}  #"children":[]
+			a["children"].append( b ) 
+		dic["children"].append( a ) 
+	return dic 
+
+
 '''
\ No newline at end of file
